Clazz.declarePackage("javajs.api");
Clazz.declareInterface(javajs.api, "GenericLineReader");
;//5.0.1-v7 Thu May 08 14:17:10 CDT 2025
